BlockIO

Trait BlockIO 

pub trait BlockIO {
    type Item;

    // Required methods
    fn from_block(block: &Block) -> Result<Self::Item, CellParseError>;
    fn to_block(&self, order: usize) -> Block;
}
Convert between the impl type and Block Usage: convert from parsed block to edit data, then convert back to block to insert back to the HashMap<&str, CELLObject>

Required Associated Types

Required Methods

fn from_block(block: &Block) -> Result<Self::Item, CellParseError>

fn to_block(&self, order: usize) -> Block

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors